Install
=======

Installation
------------

To use graphe, first install it using pip:

.. code-block:: console

   (.venv) $ pip install graphe


Local Install
-------------

To install locally from source

.. code-block:: console

   $ pip install .
